@@ -1,6 +1,6 @@
 DATA = {
   "Examples": [], 
-  "dist": "python-qosf-1.1.0-py_0", 
+  "dist": "python-qosf-1.1.1-py_0", 
   "python-scripts": [], 
   "site-packages": [
     "QOpenScienceFramework/__init__.py", 
@@ -13,7 +13,12 @@ DATA = {
     "QOpenScienceFramework/manager.py", 
     "QOpenScienceFramework/settings.json", 
     "QOpenScienceFramework/test-settings.json", 
-    "QOpenScienceFramework/widgets.py", 
+    "QOpenScienceFramework/util.py", 
+    "QOpenScienceFramework/widgets/__init__.py", 
+    "QOpenScienceFramework/widgets/loginwindow.py", 
+    "QOpenScienceFramework/widgets/osfexplorer.py", 
+    "QOpenScienceFramework/widgets/projecttree.py", 
+    "QOpenScienceFramework/widgets/userbadge.py", 
     "humanize-0.5.1-py2.7.egg-info/PKG-INFO", 
     "humanize-0.5.1-py2.7.egg-info/SOURCES.txt", 
     "humanize-0.5.1-py2.7.egg-info/dependency_links.txt", 
@@ -32,12 +37,12 @@ DATA = {
     "humanize/locale/ru_RU/LC_MESSAGES/humanize.po", 
     "humanize/number.py", 
     "humanize/time.py", 
-    "python_qosf-1.1.0-py2.7.egg-info/PKG-INFO", 
-    "python_qosf-1.1.0-py2.7.egg-info/SOURCES.txt", 
-    "python_qosf-1.1.0-py2.7.egg-info/dependency_links.txt", 
-    "python_qosf-1.1.0-py2.7.egg-info/not-zip-safe", 
-    "python_qosf-1.1.0-py2.7.egg-info/requires.txt", 
-    "python_qosf-1.1.0-py2.7.egg-info/top_level.txt"
+    "python_qosf-1.1.1-py2.7.egg-info/PKG-INFO", 
+    "python_qosf-1.1.1-py2.7.egg-info/SOURCES.txt", 
+    "python_qosf-1.1.1-py2.7.egg-info/dependency_links.txt", 
+    "python_qosf-1.1.1-py2.7.egg-info/not-zip-safe", 
+    "python_qosf-1.1.1-py2.7.egg-info/requires.txt", 
+    "python_qosf-1.1.1-py2.7.egg-info/top_level.txt"
   ]
 }
 ## END DATA
